/*
  Bear Engine

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file audio/sample.cpp
 * \brief Implementaion of the bear::audio::sample class.
 * \author Julien Jorge
 */
#include "audio/sample.hpp"

#include "audio/sound_manager.hpp"
#include <cstdlib>

/*----------------------------------------------------------------------------*/
/**
 * \brief Constructor.
 */
bear::audio::sample::sample()
  : m_manager(NULL)
{

} // sample::sample()

/*----------------------------------------------------------------------------*/
/**
 * \brief Constructor.
 * \param owner The instance of sound_manager who manage the sound.
 */
bear::audio::sample::sample( sound_manager& owner )
  : m_manager(&owner)
{

} // sample::sample()

/*----------------------------------------------------------------------------*/
/**
 * \brief Destructor.
 */
bear::audio::sample::~sample()
{
  stop();

  if (m_manager != NULL)
    m_manager->sample_deleted(this);
} // sample::~sample()

/*----------------------------------------------------------------------------*/
/**
 * \brief Start to play the sound.
 */
void bear::audio::sample::play()
{
  stop();
} // sample::play()

/*----------------------------------------------------------------------------*/
/**
 * \brief Start to play the sound, with an effect.
 * \param effect The effect applied to the sound.
 */
void bear::audio::sample::play( const sound_effect& effect )
{
  stop();
} // sample::play()

/*----------------------------------------------------------------------------*/
/**
 * \brief Stop the sample.
 */
void bear::audio::sample::stop()
{
  sample_finished();
} // sample::stop()

/*----------------------------------------------------------------------------*/
/**
 * \brief Get the effect of the sample.
 */
bear::audio::sound_effect bear::audio::sample::get_effect() const
{
  return sound_effect();
} // sample::get_effect()

/*----------------------------------------------------------------------------*/
/**
 * \brief Set the effect of the sample.
 * \param effect The new effect.
 */
void bear::audio::sample::set_effect( const sound_effect& effect )
{

} // sample::set_effect()

/*----------------------------------------------------------------------------*/
/**
 * \brief Set the volume of the sample (for sound_manager only).
 * \param v The volume.
 */
void bear::audio::sample::set_volume( double v )
{

} // sample::set_volume()

/*----------------------------------------------------------------------------*/
/**
 * \brief Inform the manager that this sample is finished.
 */
void bear::audio::sample::sample_finished()
{
  if (m_manager != NULL)
    m_manager->sample_finished(this);
} // sample::sample_finished()
