/*
  Bear Engine

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file model_action.cpp
 * \brief Implementation of the bear::engine::model_action class.
 * \author Julien Jorge
 */
#include "engine/model_action.hpp"

/*----------------------------------------------------------------------------*/
/**
 * \brief Constructor.
 */
bear::engine::model_action::model_action()
{

} // model_action::model_action()

/*----------------------------------------------------------------------------*/
/**
 * \brief Constructor.
 * \param anim The animation of the action.
 * \param s The name of the sound to play.
 */
bear::engine::model_action::model_action
( const visual::animation& anim, const std::string& s )
  : m_animation(anim), m_sound(s)
{

} // model_action::model_action()

/*----------------------------------------------------------------------------*/
/**
 * \brief Get the animation of the action.
 */
const bear::visual::animation& bear::engine::model_action::get_animation() const
{
  return m_animation;
} // model_action::get_animation()

/*----------------------------------------------------------------------------*/
/**
 * \brief Get the name of the sound to play.
 */
const std::string& bear::engine::model_action::get_sound_name() const
{
  return m_sound;
} // model_action::get_sound_name()
