/*
  Bear Engine

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file model_actor.cpp
 * \brief Implementation of the bear::engine::model_actor class.
 * \author Julien Jorge
 */
#include "engine/model_actor.hpp"

/*----------------------------------------------------------------------------*/
/**
 * \brief Get an action of the model.
 * \param action_name The name of the action.
 */
const bear::engine::model_action&
bear::engine::model_actor::get_action( const std::string& action_name ) const
{
  CLAW_PRECOND( m_actions.find(action_name) != m_actions.end() );

  return m_actions.find(action_name)->second;
} // model_actor::get_action()

/*----------------------------------------------------------------------------*/
/**
 * \brief Add an action to the model.
 * \param name The name of the action.
 * \param a The action to add.
 */
void bear::engine::model_actor::add_action
( const std::string& name, const model_action& a )
{
  m_actions[name] = a;
} // model_actor::add_action()

/*----------------------------------------------------------------------------*/
/**
 * \brief Copy the actions of a model.
 * \param that The model to copy.
 */
void bear::engine::model_actor::assign_model( const model_actor& that )
{
  *this = that;
} // model_actor::assign_model()
