/*
  Bear Engine

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file input_local_reader.cpp
 * \brief Implementation of the bear::engine::input_local_reader class.
 * \author Julien Jorge
 */
#include "engine/input_reader/input_local_reader.hpp"

/*----------------------------------------------------------------------------*/
/**
 * \brief Constructor.
 * \param player_index The index of the player to control.
 * \param layout The controller layout of the controlled player.
 */
bear::engine::input_local_reader::input_local_reader
( unsigned int player_index, const controller_layout& layout )
  : input_base_local_reader( player_index, layout )
{
  // nothing to do
} // input_local_reader::input_local_reader()

/*----------------------------------------------------------------------------*/
/**
 * \brief Tell the player to start an action.
 * \param action The action to send.
 */
void bear::engine::input_local_reader::send_start_action_to_player
( player::action action )
{
  if (m_player)
    m_player->start_action( action );
} // input_local_reader::send_start_action_to_player()

/*----------------------------------------------------------------------------*/
/**
 * \brief Tell the player to stop an action.
 * \param action The action to send.
 */
void
bear::engine::input_local_reader::send_stop_action_to_player
( player::action action )
{
  if (m_player)
    m_player->stop_action( action );
} // input_local_reader::send_stop_action_to_player()

/*----------------------------------------------------------------------------*/
/**
 * \brief Apply an action to the player.
 * \param action The action to send.
 */
void bear::engine::input_local_reader::send_action_to_player
( player::action action )
{
  if (m_player)
    m_player->do_action( action );
} // input_local_reader::send_action_to_player()
