/*
  Bear Engine

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file level_object.hpp
 * \brief The basic physical item of our game.
 * \author Julien Jorge
 */
#ifndef __ENGINE_LEVEL_OBJECT_HPP__
#define __ENGINE_LEVEL_OBJECT_HPP__

#include "engine/class_export.hpp"
#include "engine/level_globals.hpp"

namespace bear
{
  namespace engine
  {
    class level;

    /**
     * \brief The basic physical item of our game.
     * \author Julien Jorge
     *  - \a pos_x: \c The x-coordinate,
     *  - \a pos_y: \c The y-coordinate,
     *  - \a height: \c The height of the box,
     *  - \a width: \c The width of the box,
     *  - \a mass: \c Mass of the item,
     *  - \a angle: \c Angle of the item.
     */
    class ENGINE_EXPORT level_object
    {
    public:
      level_object();

      void set_level( level& lvl );
      level& get_level() const;

      level_globals& get_level_globals() const;

    private:
      /** \brief The level in which I am. */
      level* m_level;

    }; // class level_object

  } // namespace engine
} // namespace bear

#endif // __ENGINE_LEVEL_OBJECT_HPP__
