/*
  Bear Engine

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file model_action.hpp
 * \brief An action of a model.
 * \author Julien Jorge
 */
#ifndef __ENGINE_MODEL_ACTION_HPP__
#define __ENGINE_MODEL_ACTION_HPP__

#include "engine/class_export.hpp"

#include "visual/animation.hpp"
#include <string>

namespace bear
{
  namespace engine
  {
    /**
     * \brief An action of a model.
     * \author Julien Jorge
     */
    class ENGINE_EXPORT model_action
    {
    public:
      model_action();
      model_action( const visual::animation& anim, const std::string& s );

      const visual::animation& get_animation() const;
      const std::string& get_sound_name() const;

    private:
      /** \brief The animation to play. */
      visual::animation m_animation;

      /** \brief The name of the sound to play. */
      std::string m_sound;

    }; // class model_action
  } // namespace engine
} // namespace bear

#endif // __ENGINE_MODEL_ACTION_HPP__
