/*
  Bear Engine

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file with_decoration.hpp
 * \brief Inherit from this item to have a sprite or an animation.
 * \author Sebastien Angibaud
 */
#ifndef __ENGINE_WITH_DECORATION_HPP__
#define __ENGINE_WITH_DECORATION_HPP__

#include "visual/animation.hpp"
#include "visual/sprite.hpp"
#include "engine/class_export.hpp"

namespace bear
{
  namespace engine
  {
    /**
     * \brief Inherit from this item to have a sprite or an animation.
     * \author Julien Jorge
     */
    class ENGINE_EXPORT with_decoration
    {
    public:
      with_decoration();
      with_decoration( const with_decoration& that );
      ~with_decoration();

      with_decoration& operator=( const with_decoration& that );

      void set_sprite( const visual::sprite& spr );
      void set_animation( const visual::animation& anim );

      visual::sprite& get_sprite();
      visual::animation& get_animation();
      const visual::sprite& get_sprite() const;
      const visual::animation& get_animation() const;

      bool has_sprite() const;
      bool has_animation() const;

      void remove_sprite();
      void remove_animation();

      void clear();

    private:
      void assign( const with_decoration& that );

    private:
      /** \brief The animation, if any. */
      visual::animation* m_animation;

      /** \brief The sprite, if any. */
      visual::sprite* m_sprite;

    }; // class with_decoration
  } // namespace engine
} // namespace bear

#endif // __ENGINE_WITH_DECORATION_HPP__
