/*
  Bear Engine

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file dynamic_item.cpp
 * \brief Implementation of the bear::universe::dynamic_item class.
 * \author Sebastien Angibaud
 */

#include "universe/dynamic_item.hpp"

/*----------------------------------------------------------------------------*/
/**
 * \brief Constructor.
 *
 */
bear::universe::dynamic_item::dynamic_item()
  : m_item(NULL)
{

} // dynamic_item::dynamic_item()

/*----------------------------------------------------------------------------*/
/**
 * \brief Constructor.
 *
 * \param item The considered item.
 */
bear::universe::dynamic_item::dynamic_item(physical_item* item)
  : m_item(item), m_initial_state(*item)
{

} // dynamic_item::dynamic_item()

/*----------------------------------------------------------------------------*/
/**
 * \brief Clear the neighbourhood.
 *
 */
void bear::universe::dynamic_item::clear_neighbourhood()
{
  m_neighbourhood.clear();
} // dynamic_item::clear_neighboorhood()

      
/*----------------------------------------------------------------------------*/
/**
 * \brief Add a neighbour if it is not the current item.
 *
 * \param neighbourg The new neighbour.
 */
void bear::universe::dynamic_item::add_neighbour(neighbour_type neighbour)
{
  if ( neighbour != m_item ) 
    m_neighbourhood.insert(neighbour);
} // dynamic_item::add_neighbour()


/*----------------------------------------------------------------------------*/
/**
 * \brief Get the neighbourhood.
 */
const bear::universe::dynamic_item::neighbourhood_type&
bear::universe::dynamic_item::get_neighbourhood() const
{
  return m_neighbourhood;
} // dynamic_item::get_neighbourhood() 


/*----------------------------------------------------------------------------*/
/** \brief Get the item reference.
 */
bear::universe::dynamic_item::neighbour_type
bear::universe::dynamic_item::get_item()
{
  return m_item;
} // dynamic_item::get_item() 

/*----------------------------------------------------------------------------*/
/** \brief Get the item reference.
 */
const bear::universe::physical_item_state& 
bear::universe::dynamic_item::get_initial_state() const
{
  return m_initial_state;
} // dynamic_item::get_initial_state()
