/*
  Bear Engine

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file dynamic_item_set.cpp
 * \brief Implementation of the bear::universe::dynamic_item_set class.
 * \author Angibaud Sebastien
 */
#include "universe/dynamic_item_set.hpp"

/*----------------------------------------------------------------------------*/
/**
 * \brief Add a dynamic item in the set.
 * \param item The item to insert.
 */
void bear::universe::dynamic_item_set::add_item(key_type item)
{
  items_map_type::iterator it;

  it = m_items.find(item);

  if ( it == m_items.end() )
    m_items[item] = dynamic_item(item);
} // dynamic_item_set::add_item()

/*----------------------------------------------------------------------------*/
/**
 * \brief Get the dynamic_item of an item. If the item is not in the map, 
 * it is added.
 * \param item The item searched.
 */
bear::universe::dynamic_item_set::value_type& 
bear::universe::dynamic_item_set::operator[] (key_type item)
{
  items_map_type::iterator it;

  it = m_items.find(item);

  if ( it == m_items.end() ) 
    {
      // creation of a dynamic item
      m_items[item] = dynamic_item(item);

      return m_items[item];
    }
  else
    return it->second;
} // dynamic_item_set::operator[]()

/*----------------------------------------------------------------------------*/
/**
 * \brief Get an iterator at the beginning of the map.
 */
bear::universe::dynamic_item_set::iterator_type 
bear::universe::dynamic_item_set::begin()
{
  return m_items.begin();
} // dynamic_item_set::begin()


/*----------------------------------------------------------------------------*/
/**
 * \brief Get an iterator at the end of the map.
 */
bear::universe::dynamic_item_set::iterator_type 
bear::universe::dynamic_item_set::end()
{
  return m_items.end();
} // dynamic_item_set::end()

/*----------------------------------------------------------------------------*/
/**
 * \brief Get a const iterator at the beginning of the map.
 */
bear::universe::dynamic_item_set::const_iterator_type 
bear::universe::dynamic_item_set::const_begin() const
{
  return m_items.begin();
} // dynamic_item_set::const_begin()

/*----------------------------------------------------------------------------*/
/**
 * \brief Get a const iterator at the end of the map.
 */
bear::universe::dynamic_item_set::const_iterator_type 
bear::universe::dynamic_item_set::const_end() const
{
  return m_items.end();
} // dynamic_item_set::const_end()
