/*
  Bear Engine

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file collision_detection.hpp
 * \brief This class detects collisions an item and its neighbourhood.
 * \author Julien Jorge
 */
#ifndef __UNIVERSE_COLLISION_DETECTION_HPP__
#define __UNIVERSE_COLLISION_DETECTION_HPP__

#include "universe/physical_item.hpp"
#include "universe/dynamic_item_set.hpp"

#include <claw/avl.hpp>
#include <list>

#include "universe/class_export.hpp"

namespace bear
{
  namespace universe
  {
    /**
     * \brief This class detects collisions between an item and 
     * its neighbourhood.
     * \author Julien Jorge
     */
    class UNIVERSE_EXPORT collision_detection
    {
    private:
      typedef std::pair<physical_item*, physical_item*> item_pair;

    public:
      collision_detection( dynamic_item_set& dynamic_items );

      bool detect( dynamic_item& d_item, bool can_move_item_state);

    private:
      void collision
      ( physical_item& self, physical_item& that,
        const physical_item_state& old_self,
        const physical_item_state& old_that ) const;

    private:
      /** \brief The set pair already corrected. */
      claw::avl<item_pair> m_corrected;

      /** \brief The set of dynamic items in the current progress. */
      dynamic_item_set& m_dynamic_items;

    }; // class collision_detection
  } // namespace universe
} // namespace bear

#endif // __UNIVERSE_COLLISION_DETECTION_HPP__
