/*
  Bear Engine

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file dynamic_item.hpp
 * \brief A class which represents an item during a progress iteration.
 * \author Sebastien Angibaud
 */
#ifndef __UNIVERSE_DYNAMIC_ITEM_HPP__
#define __UNIVERSE_DYNAMIC_ITEM_HPP__

#include <set>

#include "universe/physical_item.hpp"

namespace bear
{
  namespace universe
  {
    /**
     * \brief A class which represents an item during a progress iteration.
     * \author Sebastien Angibaud
     */
    class UNIVERSE_EXPORT dynamic_item
    {
    public:
      /** \brief The type of a neighbour. */
      typedef physical_item* neighbour_type;

      /** \brief The type of neighbourhood. */
      typedef std::set<neighbour_type> neighbourhood_type;

      /** \brief The type of a iterator of neighbourhood. */
      typedef neighbourhood_type::iterator neighbourhood_iterator_type;

    public:
      dynamic_item();
      dynamic_item( physical_item* item );

      void clear_neighbourhood();
      
      void add_neighbour(neighbour_type neighbour);

      const neighbourhood_type& get_neighbourhood() const;

      neighbour_type get_item();
      const physical_item_state& get_initial_state() const;
     
    private:
      /** \brief The item. */
      physical_item* m_item; 

      /** \brief The initial state of the item. */
      physical_item_state m_initial_state;

      /** \brief The neighbour of the item. */
      neighbourhood_type m_neighbourhood; 
    }; // class dynamic_item
  } // namespace universe
} // namespace bear

#endif // __UNIVERSE_DYNAMIC_ITEM_HPP__
