/*
  Bear Engine

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file dynamic_item_set.hpp
 * \brief A class which represents a set of dynamic_item.
 * \author Sebastien Angibaud
 */
#ifndef __UNIVERSE_DYNAMIC_ITEM_SET_HPP__
#define __UNIVERSE_DYNAMIC_ITEM_SET_HPP__

#include "universe/dynamic_item.hpp"

#include <map>

namespace bear
{
  namespace universe
  {
    /**
     * \brief A class which represents a set of dynamic_item.
     */
    class UNIVERSE_EXPORT dynamic_item_set
    {
    public:
      /** \brief The type of the key. */
      typedef physical_item* key_type;

      /** \brief The type of the value. */
      typedef dynamic_item value_type;

      /** \brief The type of the map. */
      typedef std::map<key_type,value_type> items_map_type;

      /** \brief The type of an iterator on the map. */
      typedef items_map_type::iterator iterator_type;
      
      /** \brief The type of an const iterator on the map. */
      typedef items_map_type::const_iterator const_iterator_type;

    public:
      void add_item(key_type item);

      value_type& operator[] (key_type item);

      iterator_type begin();
      iterator_type end();

      const_iterator_type const_begin() const;
      const_iterator_type const_end() const;

    private:
      /** \brief The map of <item,dynamic item>. */
      items_map_type m_items;
    }; // class dynamic_item_set
  } // namespace universe
} // namespace bear

#endif // __UNIVERSE_DYNAMIC_ITEM_SET_HPP__
