/*
  Bear Engine

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file item_handle.hpp
 * \brief Safe way to point an item that could die between two use.
 * \author Julien Jorge
 */
#ifndef __UNIVERSE_ITEM_HANDLE_HPP__
#define __UNIVERSE_ITEM_HANDLE_HPP__

#include "universe/class_export.hpp"

namespace bear
{
  namespace universe
  {
    class physical_item;

    /**
     * \brief Safe way to point an item that could die between two use.
     * \author Julien Jorge
     */
    class UNIVERSE_EXPORT item_handle
    {
    public:
      item_handle();
      item_handle( physical_item* item );
      item_handle( physical_item& item );
      item_handle( const item_handle& that );
      ~item_handle();

      physical_item* get();
      const physical_item* get() const;

      physical_item& operator*();
      const physical_item& operator*() const;
      physical_item* operator->();
      const physical_item* operator->() const;

      item_handle& operator=( physical_item* item );
      item_handle& operator=( const item_handle& that );

      bool operator==( const physical_item* item ) const;
      bool operator==( const item_handle& that ) const;
      bool operator!=( const physical_item* item ) const;
      bool operator!=( const item_handle& that ) const;
      bool operator<( const item_handle& that ) const;

    private:
      /** \brief The critical item. */
      physical_item* m_item;

    }; // class item_handle
  } // namespace universe
} // namespace bear

#endif // __UNIVERSE_ITEM_HANDLE_HPP__
