/*
  Bear Engine

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file visual/code/scene_element.cpp
 * \brief Implementation of the visual::scene_element.
 * \author Julien Jorge
 */
#include "visual/scene_element.hpp"

/*----------------------------------------------------------------------------*/
/**
 * \brief Constructeur.
 * \param e The effective element of the scene.
 */
bear::visual::scene_element::scene_element( const base_scene_element& e )
  : m_elem(e.clone())
{

} // scene_element::scene_element()

/*----------------------------------------------------------------------------*/
/**
 * \brief Get a rectangle where the element is completely opaque.
 */
bear::visual::rectangle_type bear::visual::scene_element::get_opaque_box() const
{
  return m_elem->get_opaque_box();
} // scene_element::get_opaque_box()

/*----------------------------------------------------------------------------*/
/**
 * \brief Get a rectangle bounding the element.
 */
bear::visual::rectangle_type
bear::visual::scene_element::get_bounding_box() const
{
  return m_elem->get_bounding_box();
} // scene_element::get_bounding_box()

/*----------------------------------------------------------------------------*/
/**
 * \brief Split the element in sub elements
 * \param boxes The boxes describing how to split the element.
 * \param output The resulting elements (they are inserted to the front.
 */
void bear::visual::scene_element::burst
( const rectangle_list& boxes, scene_element_list& output ) const
{
  m_elem->burst(boxes, output);
} // scene_element::burst()

/*----------------------------------------------------------------------------*/
/**
 * \brief Render the element on a screen.
 * \param scr The screen on which we render the element.
 */
void bear::visual::scene_element::render( base_screen& scr ) const
{
  m_elem->render(scr);
} // scene_element::render()
