/*
  Bear Engine

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file sdl_image.hpp
 * \brief SDL implementation of an image.
 * \author Julien Jorge
 */
#ifndef __VISUAL_SDL_IMAGE_HPP__
#define __VISUAL_SDL_IMAGE_HPP__

#include "visual/base_image.hpp"

#include <SDL/SDL.h>
#include <claw/image.hpp>
#include <map>

namespace bear
{
  namespace visual
  {
    /**
     * \brief SDL implementation of an image.
     * \author Julien Jorge
     */
    class VISUAL_EXPORT sdl_image:
      public base_image
    {
    public:
      sdl_image( const claw::graphic::image& data );
      sdl_image( const sdl_image& that );
      ~sdl_image();

      base_image* clone() const;

      const SDL_Surface* get_surface() const;
      claw::math::coordinate_2d<unsigned int> size() const;
      bool has_transparency() const;

      sdl_image& operator=( const sdl_image& that );

    private:
      void create_texture( const claw::graphic::image& pixels );

      void register_texture() const;
      void release_texture();

    private:
      /** \brief The surface containing the texture. */
      SDL_Surface* m_texture;

      /** \brief Image's size. */
      claw::math::coordinate_2d<unsigned int> m_size;

      /** \brief Is there any transparent pixel in the image ? */
      bool m_has_transparency;

      /** \brief Number of instances using this texture. */
      static std::map<SDL_Surface*, unsigned int> s_texture_references;

    }; // class sdl_image
  } // namespace visual
} // namespace bear

#endif // __VISUAL_SDL_IMAGE_HPP__
