/*
  Bear Engine

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file applied_forced_movement.cpp
 * \brief Implementation of the bear::applied_forced_movement class.
 * \author Julien Jorge
 */
#include "generic_items/applied_forced_movement.hpp"

#include "engine/export.hpp"

BASE_ITEM_EXPORT( applied_forced_movement, bear )

/*----------------------------------------------------------------------------*/
/**
 * \brief Constructor.
 */
bear::applied_forced_movement::applied_forced_movement()
  : m_actor(NULL), m_movement(NULL)
{

} // applied_forced_movement::applied_forced_movement()

/*----------------------------------------------------------------------------*/
/**
 * \brief Set a field of type <item>.
 * \param name The name of the field.
 * \param value The value of the field.
 */
bool bear::applied_forced_movement::set_item_field
( const std::string& name, engine::base_item* value )
{
  bool result = true;

  if ( name == "actor" )
    m_actor = value;
  else if ( name == "movement" )
    m_movement = value;
  else
    result = super::set_item_field(name, value);

  return result;
} // applied_forced_movement::set_item_field()

/*----------------------------------------------------------------------------*/
/**
 * \brief Tell if all required fields are initialized.
 */
bool bear::applied_forced_movement::is_valid() const
{
  return (m_actor != NULL) && (m_movement != NULL)
    && m_movement->has_forced_movement() && super::is_valid();
} // applied_forced_movement::is_valid()

/*----------------------------------------------------------------------------*/
/**
 * \brief Initialize the item.
 */
void bear::applied_forced_movement::build()
{
  m_actor->set_forced_movement(m_movement->get_forced_movement());

  kill();
} // applied_forced_movement::build()
