/*
  Bear Engine

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [Bear] in the subject of your mails.
*/
/**
 * \file elastic_link_creator.hpp
 * \brief This class creates a forced movement of type "elastic_link", applies it
 *        to itself then die.
 * \author Julien Jorge
 */
#ifndef __BEAR_ELASTIC_LINK_CREATOR_HPP__
#define __BEAR_ELASTIC_LINK_CREATOR_HPP__

#include "engine/base_item.hpp"

namespace bear
{
  /**
   * \brief This class creates an elastic_link between two items then die.
   *
   * The fields of this item are
   *  - \a first_item: (item) \b [required] \c the item at the first end of the
   *    elastic,
   *  - \a second_item: (item) \b [required] \c the item at the second end of
   *    the elastic,
   *  - \a strength: (real) \c the strength of the elastic (default = 1),
   *  - \a length: (real) \c the length of the elastic (default = auto).
   *
   * \author Julien Jorge
   */
  class elastic_link_creator:
    public engine::base_item
  {
  public:
    /** \brief The type of the parent class. */
    typedef engine::base_item super;

  public:
    elastic_link_creator();

    bool set_real_field( const std::string& name, double value );
    bool set_item_field( const std::string& name, engine::base_item* value );
    bool is_valid() const;

    void build();

  private:
    /** \brief The strength of the elastic. */
    double m_strength;

    /** \brief The length of the elastic. */
    universe::coordinate_type m_length;

    /** \brief The item at the first end of the elastic. */
    engine::base_item* m_first_item;

    /** \brief The item at the second end of the elastic. */
    engine::base_item* m_second_item;

  }; // class elastic_link_creator
} // namespace bear

#endif // __BEAR_ELASTIC_LINK_CREATOR_HPP__
