/*
  Plee the Bear

  Copyright (C) 2005-2008 Julien Jorge, Sebastien Angibaud

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

  contact: plee-the-bear@gamned.org

  Please add the tag [PTB] in the subject of your mails.
*/
/**
 * \file status_layer.hpp
 * \brief The status layer contains the area where are printed the score,
 *        energy, remaining lifes of the players.
 * \author Julien Jorge
 */
#ifndef __PTB_STATUS_LAYER_HPP__
#define __PTB_STATUS_LAYER_HPP__

#include "engine/layer/gui_layer.hpp"
#include "engine/pointer_to_player.hpp"
#include "gui/static_text.hpp"

namespace ptb
{
  /**
   * \brief The status layer contains the area where are printed the score,
   *        energy, remaining lifes of the players.
   */
  class status_layer:  
    public bear::engine::gui_layer
  {
  private:
    /**
     * \brief All the informations we want to show about a player.
     */
    class player_status
    {
    public:
      player_status( const bear::visual::sprite& e, const bear::text::font& f,
                     const bear::engine::pointer_to_player& p );

      void update();

    public:
      /** \brief Level of energy. */
      bear::visual::sprite energy;

      /** \brief Number of stone. */
      bear::gui::static_text stones;

      /** \brief Pointer to the player. */
      bear::engine::pointer_to_player player;

    }; // class player_status

  public:
    status_layer();
    virtual ~status_layer();

    void build();
    void progress( bear::universe::time_type elapsed_time );
    void render( bear::visual::screen& screen ) const;

  private:
    void render_player1( bear::visual::screen& screen ) const;
    void render_player2( bear::visual::screen& screen ) const;

    void progress_time( bear::universe::time_type elapsed_time );

  private:
    /** \brief Data of the first player. */
    player_status* m_data_1;

    /** \brief Data of the second player. */
    player_status* m_data_2;

    /** \brief First font for time text. */
    bear::text::font m_font_1;

    /** \brief Second font for time text. */
    bear::text::font m_font_2;
    
    /** \brief The component in which we show the time. */
    bear::gui::static_text* m_text_time;

    /** \brief Sprite for if the player have no energy. */
    bear::visual::sprite m_sprite_no_energy;

    /** \brief Sprite of stone. */
    bear::visual::sprite m_sprite_stone;

    /** \brief The width of the energy sprite. */
    const static unsigned int s_width_energy;

  }; // class status_layer
} // namespace ptb

#endif // __PTB_STATUS_LAYER_HPP__
